@@ -10,7 +10,7 @@ module ActiveModel
     MAJOR = 6
     MINOR = 0
     TINY  = 6
-    PRE   = nil
+    PRE   = "1"
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
